/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.session;

import java.io.Serializable;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

/**
 * This bean will later contain information about the user of this session (like user name and authorization). For the moment every user will be a guest user.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@SessionScoped
public final class UserBean implements Serializable {

	/**
	 * The serial version UID.
	 */
	private static final long serialVersionUID = 3942693805646862667L;
	/**
	 * This field contains the name of the user.
	 */
	private final String userName;

	/**
	 * Creates a new instance of this class. The user name is set to "Guest".
	 */
	public UserBean() {
		this.userName = "Guest";
	}

	/**
	 * Returns the name of the user of the current session.
	 * 
	 * @return The user name.
	 */
	public String getUserName() {
		return this.userName;
	}

}
